-- Copyright (c) 2012 Cloudera, Inc. All rights reserved.
--
-- Version 4509 of the CMF schema.
--
-- Create base role config groups as needed and update existing roles
-- to use them.
--

update SCHEMA_VERSION set VERSION=4509;

-- Insert new groups for each service/roletype combination (from existing
-- roles) that's not already represented by a group.
insert into ROLE_CONFIG_GROUPS (ROLE_CONFIG_GROUP_ID, SERVICE_ID, ROLE_TYPE, NAME)
  select LAST_GROUP.MAX_ID + rownum ROLE_CONFIG_GROUP_ID, inner_query.*
  from
    (select distinct r.SERVICE_ID, r.ROLE_TYPE, r.ROLE_TYPE || '_BASE'
     from ROLES r left join ROLE_CONFIG_GROUPS g
     on r.SERVICE_ID=g.SERVICE_ID and r.ROLE_TYPE=g.ROLE_TYPE
     where g.SERVICE_ID is null) inner_query,
    (select nvl(max(ROLE_CONFIG_GROUP_ID), 0) MAX_ID
     from ROLE_CONFIG_GROUPS) LAST_GROUP;

-- Update all roles to point to the appropriate role config group.
update ROLES r
  set ROLE_CONFIG_GROUP_ID=(
    select ROLE_CONFIG_GROUP_ID
    from ROLE_CONFIG_GROUPS g
    where r.ROLE_TYPE=g.ROLE_TYPE and
          r.SERVICE_ID=g.SERVICE_ID);

-- Now that every role has a group, make the foreign key not nullable.
alter table ROLES modify (
  ROLE_CONFIG_GROUP_ID constraint NOT_NULL_ROLES_RCG_ID not null);
